SystemOrganization addCategory: #'Essential-SUnit'!
SystemOrganization addCategory: #'Essential-SLint'!

!BrowserEnvironment methodsFor: '*essential' stamp: 'lr 10/26/2005 21:34'!
- anEnvironment
	^ self & anEnvironment not.! !

!BrowserEnvironment methodsFor: '*essential' stamp: 'lr 10/26/2005 22:04'!
xor: anEnvironment
	^ (self - anEnvironment) | (anEnvironment - self).! !

TestResource subclass: #ESLintTestResource
	instanceVariableNames: 'context environments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESLintTestResource methodsFor: 'accessing' stamp: 'lr 10/26/2005 15:40'!
context
	^ context! !

!ESLintTestResource methodsFor: 'accessing' stamp: 'lr 10/26/2005 21:22'!
environmentFor: aTestCase
	^ environments at: aTestCase class ifAbsentPut: [ aTestCase environment ].! !

!ESLintTestResource methodsFor: 'running' stamp: 'lr 10/26/2005 16:19'!
setUp
	super setUp.
	context := SmalllintContext new.
	environments := IdentityDictionary new.! !

!ESLintTestResource methodsFor: 'running' stamp: 'lr 10/26/2005 16:18'!
tearDown
	super tearDown.
	context := environments := nil.! !

Object subclass: #ESCoverage
	instanceVariableNames: 'coverage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SUnit'!

!ESCoverage methodsFor: 'accessing' stamp: 'lr 10/24/2005 22:45'!
environment
	| environment |
	environment := SelectorEnvironment onEnvironment: BrowserEnvironment new.
	coverage keysAndValuesDo: [ :key :value |
		key isBehavior ifTrue: [
			value do: [ :each |
				environment addClass: key selector: each ] ] ].
	^ environment.! !

!ESCoverage methodsFor: 'initialization' stamp: 'lr 10/24/2005 21:17'!
initialize
	super initialize.
	coverage := IdentityDictionary new.! !

!ESCoverage methodsFor: 'execution' stamp: 'lr 10/27/2005 00:01'!
run: aBlock
	| previous |
	previous := aBlock.
	thisContext sender
		runSimulated: aBlock
		contextAtEachStep: [ :current |
			current == previous ifFalse: [
				previous sender isNil ifFalse: [
					(coverage 
						at: (current receiver class 
							whichClassIncludesSelector: current selector)
						ifAbsentPut: [ IdentitySet new ])
							add: current selector ]. 
				previous := current ] ].! !

Object subclass: #ESLintScope
	instanceVariableNames: 'environment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESLintScope class methodsFor: 'instance-creation' stamp: 'lr 10/26/2005 21:18'!
on: anEnvironment
	^ self basicNew
		setEnvironment: anEnvironment;
		yourself.! !

!ESLintScope methodsFor: 'accessing' stamp: 'lr 10/26/2005 19:57'!
environment
	" Answer the environment that should be searched. "

	^ environment! !

!ESLintScope methodsFor: 'initialization' stamp: 'lr 10/26/2005 21:13'!
initialize
	super initialize.
	self setEnvironment: BrowserEnvironment new.! !

!ESLintScope methodsFor: 'copying' stamp: 'lr 10/26/2005 23:59'!
postCopy
	super postCopy.
	environment := self environment copy.! !

!ESLintScope methodsFor: 'running' stamp: 'lr 10/26/2005 23:59'!
run: aLintRule in: aContext
	" Run aLintRule within aContext while displaying a progress-bar. Return all the tests not being expected but failed. "

	self environment classes asArray
		do: [ :class |
			aContext selectedClass: class.
			aLintRule checkClass: aContext.
			self environment 
				selectorsForClass: class 
				do: [ :selector |
					aContext selector: selector.
					aLintRule checkMethod: aContext ] ]
		displayingProgress: (aLintRule name 
			truncateWithElipsisTo: 25).
	^ aLintRule result.! !

!ESLintScope methodsFor: 'initialization' stamp: 'lr 10/26/2005 23:59'!
setEnvironment: anEnvironment
	environment := anEnvironment.! !

Object subclass: #ESTestRunner
	instanceVariableNames: 'packages packagesSelected classes classesSelected changedList failedList failedSelected errorList errorSelected result'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SUnit'!

!ESTestRunner class methodsFor: 'instance-creation' stamp: 'lr 10/8/2005 18:35'!
open
	^ ToolBuilder open: self new.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/24/2005 19:30'!
browseReferencedClasses
	| references |
	references := classesSelected gather: [ :class |
		class methodDict gather: [ :method |
			method literals
				select: [ :each | each isVariableBinding ]
				thenCollect: [ :each | each value ] ] ].
	(BrowserEnvironment new forClasses: references asSet)
		label: 'Referenced Classes';
		openEditor.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/24/2005 19:30'!
browseSentMessages
	| references |
	references := classesSelected gather: [ :class |
		class allSelectors in: [ :filter |
			class methodDict gather: [ :method |
				(method literals copyWithoutAll: filter)
					reject: [ :each | each isVariableBinding ] ] ] ].
	self systemNavigation
		browseAllImplementorsOfList: references asSet
		title: 'Sent Messages'.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/24/2005 19:26'!
browseTestClasses
	(BrowserEnvironment new forClasses: classesSelected asSet)
		label: 'Test Classes';
		openEditor.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/10/2005 11:38'!
buildButtonsWith: aBuilder
	^ aBuilder pluggablePanelSpec new
		model: self;
		layout: #horizontal;
		children: (self buttons collect: [ :each |
			aBuilder pluggableActionButtonSpec new
				model: self; action: each; 
				color: #defaultButtonColor;
				label: (self labelForSelector: each); 
				yourself ]);
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/17/2005 09:13'!
buildClassesWith: aBuilder
	^ aBuilder pluggableMultiSelectionListSpec new
		model: self;
		list: #classList;
		menu: #classMenu:;
		getIndex: #classSelected;
		setIndex: #classSelected:;
		getSelectionList: #classAt:;
		setSelectionList: #classAt:put:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/6/2005 19:39'!
buildErrorListWith: aBuilder
	^ aBuilder pluggableListSpec new
		model: self;
		name: 'Error List';
		list: #errorList; 
		getIndex: #errorSelected; 
		setIndex: #errorSelected:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/6/2005 19:47'!
buildFailureListWith: aBuilder
	^ aBuilder pluggableListSpec new
		model: self;
		name: 'Failure List';
		list: #failedList; 
		getIndex: #failedSelected; 
		setIndex: #failedSelected:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/17/2005 09:32'!
buildPackagesWith: aBuilder
	^ aBuilder pluggableMultiSelectionListSpec new
		model: self;
		list: #packageList;
		menu: #packageMenu:;
		getIndex: #packageSelected;
		setIndex: #packageSelected:;
		getSelectionList: #packageAt:;
		setSelectionList: #packageAt:put:;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/8/2005 23:06'!
buildStatusWith: aBuilder
	^ aBuilder pluggableInputFieldSpec new
		model: self;
		color: #statusColor;
		getText: #statusText;
		yourself.! !

!ESTestRunner methodsFor: 'building' stamp: 'lr 10/12/2005 09:46'!
buildWith: aBuilder
	| window |
	window := aBuilder pluggableWindowSpec new
		model: self; label: self label; extent: self extent;
		children: (OrderedCollection new 
			add: ((self buildPackagesWith: aBuilder)
				frame: (0.00 @ 0.00 corner: 0.25 @ 0.92 );
				yourself);
			add: ((self buildClassesWith: aBuilder)
				frame: (0.25 @ 0.00 corner: 0.50 @ 0.92 );
				yourself);
			add: ((self buildStatusWith: aBuilder)
				frame: (0.50 @ 0.00 corner: 1.00 @ 0.08);
				yourself);
			add: ((self buildFailureListWith: aBuilder)
				frame: (0.50 @ 0.08 corner: 1.00 @ 0.50);
				yourself);
			add: ((self buildErrorListWith: aBuilder)
				frame: (0.50 @ 0.50 corner: 1.00 @ 0.92);
				yourself);
			add: ((self buildButtonsWith: aBuilder)
				frame: (0.00 @ 0.92 corner: 1.00 @ 1.00);
				yourself);
			yourself);
		yourself.
	^ aBuilder build: window.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/24/2005 21:01'!
buttons
	^ #( runAll runCoverage runFailed runErrors ).! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 19:58'!
classAt: anInteger
	^ classesSelected includes: (classes at: anInteger ifAbsent: [ ^ false ]).! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 22:32'!
classAt: anInteger put: aBoolean
	classesSelected := classesSelected
		perform: (aBoolean ifTrue: [ #copyWith: ] ifFalse: [ #copyWithout: ])
		with: (classes at: anInteger ifAbsent: [ ^ self ]).
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/10/2005 11:24'!
classList
	| offset ident |
	classes isEmpty ifTrue: [ ^ classes ].
	offset := classes first allSuperclasses size.
	^ classes collect: [ :each |
		ident := String 
			new: 2 * (0 max: each allSuperclasses size - offset) 
			withAll: $ .
		each isAbstract
			ifFalse: [ ident , each name ]
			ifTrue: [ 
				ident asText , each name asText 
					addAttribute: TextEmphasis italic;
					yourself ] ].! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/24/2005 19:26'!
classMenu: aMenu
	^ aMenu
		add: 'Browse classes' action: #browseTestClasses;
		add: 'Browse referenced classes' action: #browseReferencedClasses;
		add: 'Browse sent messages' action: #browseSentMessages;
		addLine;
		add: 'Select all' action: #filterSelectAll;
		add: 'Select subclasses' action: #filterSelectSubclasses;
		add: 'Select inversion' action: #filterSelectInversion;
		add: 'Select none' action: #filterSelectNone;
		addLine;
		add: 'Filter...' action: #filterClassNames;
		yourself.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 22:30'!
classSelected
	^ 0! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/8/2005 22:30'!
classSelected: anInteger
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/26/2005 15:48'!
debug: aTestCase
	aTestCase debug.! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/8/2005 18:21'!
defaultBackgroundColor
	^ Color orange.! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/10/2005 11:39'!
defaultButtonColor
	^ self defaultBackgroundColor muchLighter.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:37'!
errorList
	^ errorList collect: [ :each | each printString ].! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 19:46'!
errorSelected
	^ errorList indexOf: errorSelected.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 20:14'!
errorSelected: anInteger
	errorSelected := errorList at: anInteger ifAbsent: nil.
	self changed: #errorSelected.
	errorSelected ifNotNil: [ self debug: errorSelected ].! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/8/2005 18:39'!
extent
	^ 640 @ 480! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:37'!
failedList
	^ failedList collect: [ :each | each printString ].! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 19:47'!
failedSelected
	^ failedList indexOf: failedSelected.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 20:14'!
failedSelected: anInteger
	failedSelected := failedList at: anInteger ifAbsent: nil.
	self changed: #failedSelected.
	failedSelected ifNotNil: [ self debug: failedSelected ].! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/20/2005 20:50'!
filterClassNames
	| pattern |
	pattern := UIManager default 
		request: 'Pattern to select tests:' 
		initialAnswer: '*'.
	pattern isNil ifTrue: [ ^ self ].
	classesSelected := (classes select: [ :each | 
		pattern match: each name ]) asSet.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/20/2005 16:28'!
filterPackages
	| pattern |
	pattern := UIManager default 
		request: 'Pattern to select packages:' 
		initialAnswer: '*'.
	pattern isNil ifTrue: [ ^ self ].
	packagesSelected := (packages select: [ :each | 
		pattern match: each packageName ]) asSet.
	self changed: #packageSelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/20/2005 20:49'!
filterSelectAll
	classesSelected := classes asSet.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/20/2005 20:51'!
filterSelectInversion
	classesSelected := classes asSet 
		removeAll: classesSelected;
		yourself.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/20/2005 20:53'!
filterSelectNone
	classesSelected := Set new.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'accessing-classes' stamp: 'lr 10/20/2005 20:49'!
filterSelectSubclasses
	| classesForPackages |
	classesForPackages := self findClassesForPackages: packagesSelected.	
	classesSelected := (classesSelected gather: [ :class |
		class withAllSubclasses select: [ :each |
			classesForPackages includes: each ] ])
		asSet.
	self changed: #classSelected.! !

!ESTestRunner methodsFor: 'utilities' stamp: 'lr 10/20/2005 19:46'!
findClassesForPackages: aCollection
	| items |
	aCollection isEmpty 
		ifTrue: [ ^ TestCase allSubclasses ].
	items := aCollection gather: [ :package |
		package classes select: [ :class |
			class includesBehavior: TestCase ] ].
	^ items asSet.! !

!ESTestRunner methodsFor: 'initialization' stamp: 'lr 10/20/2005 18:51'!
initialize
	super initialize.
	failedList := errorList := Array new.
	self updatePackages; updateClasses; reset.
	self initializeSystemChanges.! !

!ESTestRunner methodsFor: 'initialization' stamp: 'lr 10/20/2005 19:57'!
initializeSystemChanges
	SystemChangeNotifier uniqueInstance
		notify: self ofSystemChangesOfItem: #class change: #Added using: #onClassChange:;
		notify: self ofSystemChangesOfItem: #class change: #Modified using: #onClassChange:;
		notify: self ofSystemChangesOfItem: #class change: #Recategorized using: #onClassChange:;
		notify: self ofSystemChangesOfItem: #class change: #Removed using: #onClassChange:;
		notify: self ofSystemChangesOfItem: #class change: #Renamed using: #onClassChange:;
		notify: self ofSystemChangesOfItem: #class change: #Reorganized using: #onClassChange:;
		notify: self ofSystemChangesOfItem: #method change: #Added using: #onMethodChange:;
		notify: self ofSystemChangesOfItem: #method change: #Modified using: #onMethodChange:;
		notify: self ofSystemChangesOfItem: #method change: #Removed using: #onMethodChange:.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/6/2005 14:07'!
label
	^ 'Test Runner' ! !

!ESTestRunner methodsFor: 'events' stamp: 'lr 10/20/2005 20:16'!
onClassChange: anEvent
	| changedClass |
	changedClass := anEvent itemClass.
	changedClass isMeta 
		ifTrue: [ ^ self ].
	(changedClass includesBehavior: TestCase)
		ifFalse: [ ^ self ].
	packages isEmpty ifTrue: [
		(packages anySatisfy: [ :each | each includesClass: changedClass ])
			ifFalse: [ ^ self ] ].
	WorldState addDeferredUIMessage: [ self updateClasses ].! !

!ESTestRunner methodsFor: 'events' stamp: 'lr 10/20/2005 20:23'!
onMethodChange: anEvent
	| changedClass |
	changedClass := anEvent itemClass.
	changedClass isMeta 
		ifTrue: [ ^ self ].
	(changedClass includesBehavior: TestCase)
		ifFalse: [ ^ self ].
	(changedClass testSelectors includes: anEvent itemSelector)
		ifFalse: [ ^ self ].
	packages isEmpty ifTrue: [
		(packages anySatisfy: [ :each | each includesClass: changedClass ])
			ifFalse: [ ^ self ] ].
	" should remember changed tests here "! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/8/2005 19:58'!
packageAt: anIndex
	^ packagesSelected includes: (packages at: anIndex ifAbsent: [ ^ false ]).! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/8/2005 22:31'!
packageAt: anInteger put: aBoolean
	packagesSelected := packagesSelected
		perform: (aBoolean ifTrue: [ #copyWith: ] ifFalse: [ #copyWithout: ])
		with: (packages at: anInteger ifAbsent: [ ^ self ]).
	self changed: #packageSelected; updateClasses.! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/8/2005 22:31'!
packageList
	^ packages collect: [ :each | each packageName ].! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/17/2005 09:35'!
packageMenu: aMenu
	^ aMenu
		add: 'Filter Packages' action: #filterPackages;
		yourself.! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/8/2005 22:29'!
packageSelected
	^ 0! !

!ESTestRunner methodsFor: 'accessing-packages' stamp: 'lr 10/8/2005 22:30'!
packageSelected: anInteger
	self changed: #packageSelected.! !

!ESTestRunner methodsFor: 'private' stamp: 'lr 10/17/2005 09:46'!
perform: selector orSendTo: otherTarget
	^ (self respondsTo: selector)
		ifTrue: [ self perform: selector ]
		ifFalse: [ otherTarget perform: selector ].! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/8/2005 22:52'!
reset
	self result: TestResult new; updateResults.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/6/2005 15:47'!
result
	^ result! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:47'!
result: aResult
	result := aResult! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/20/2005 16:28'!
runAll
	self reset; runSuite: self suiteAll.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/26/2005 14:41'!
runCoverage
	| coverage |
	self reset.
	coverage := ESCoverage new.
	self suiteAll tests
		do: [ :each | 
			coverage run: [ each run: self result ].
			self updateStatus ]
		displayingProgress: 'Testing Coverage'.
	self updateResults.
	coverage environment
		label: 'Covered Methods';
		openEditor.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/8/2005 23:02'!
runErrors
	self result instVarNamed: 'errors' put: OrderedCollection new.
	self runSuite: self suiteErrors.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/8/2005 23:02'!
runFailed
	self result instVarNamed: 'failures' put: Set new.
	self runSuite: self suiteFailed.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/26/2005 16:46'!
runSuite: aTestSuite
	aTestSuite resources do: [ :each | each reset ].
	aTestSuite tests
		do: [ :each | self runTest: each ]
		displayingProgress: (String streamContents: [ :stream |
			stream nextPutAll: 'Running '.
			aTestSuite tests size = 1
				ifTrue: [ stream nextPutAll: '1 Test' ]
				ifFalse: [ stream print: aTestSuite tests size; nextPutAll: ' Tests' ] ]).
	aTestSuite resources do: [ :each | each reset ].
	self updateResults.! !

!ESTestRunner methodsFor: 'actions' stamp: 'lr 10/8/2005 23:00'!
runTest: aTestCase
	aTestCase run: self result.
	self updateStatus.! !

!ESTestRunner methodsFor: 'utilities' stamp: 'lr 10/10/2005 08:43'!
sortClass: aFirstClass before: aSecondClass
	| first second |
	first := aFirstClass withAllSuperclasses reversed.
	second := aSecondClass withAllSuperclasses reversed.
	1 to: (first size min: second size) do: [ :index | 
		(first at: index) == (second at: index)
			ifFalse: [ ^ (first at: index) name <= (second at: index) name ] ].
	^ second includes: aFirstClass.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 23:08'!
statusColor
	result hasPassed 
		ifTrue:[ ^ Color green ].
	result hasErrors 
		ifTrue: [ ^ Color red ].
	^ Color yellow.! !

!ESTestRunner methodsFor: 'accessing-testing' stamp: 'lr 10/8/2005 22:45'!
statusText
	^ result printString.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/10/2005 09:03'!
suiteAll
	| suite |
	suite := TestSuite named: 'All'.
	classesSelected do: [ :each | 
		each isAbstract 
			ifFalse: [ each addToSuiteFromSelectors: suite ] ].
	^ suite.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/6/2005 20:19'!
suiteErrors
	^ (TestSuite named: 'Errors')
		addTests: errorList;
		yourself.! !

!ESTestRunner methodsFor: 'accessing' stamp: 'lr 10/6/2005 20:29'!
suiteFailed
	^ (TestSuite named: 'Failed')
		addTests: failedList;
		yourself.! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 10/20/2005 19:50'!
updateClasses
	| classesForPackages |
	classesForPackages := self findClassesForPackages: packagesSelected.
	classes := classesForPackages asArray
		sort: [ :a :b | self sortClass: a before: b ].
	classesSelected := classesSelected isNil
		ifTrue: [ classesSelected := classesForPackages ]
		ifFalse: [ 
			classesSelected := classesSelected
				select: [ :each | classesForPackages includes: each ] ].
	self changed: #classList; changed: #classSelected.! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 10/8/2005 22:32'!
updatePackages
	packages := PackageOrganizer default packages
		sort: [ :a :b | a packageName caseInsensitiveLessOrEqual: b packageName ].
	packagesSelected := Set new.
	self changed: #packageList; changed: #packageSelected.! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 10/12/2005 09:44'!
updateResults
	self updateStatus.
	failedList size = result failures size ifFalse: [
		failedList := result failures asArray
			sort: [ :a :b | a printString <= b printString ].
		failedSelected := nil.
		self changed: #failedList; changed: #failedSelected ].
	errorList size = result errors size ifFalse: [
		errorList := result errors asArray
			sort: [ :a :b | a printString <= b printString ].
		errorSelected := nil.
		self changed: #errorList; changed: #errorSelected ].! !

!ESTestRunner methodsFor: 'updating' stamp: 'lr 10/8/2005 23:06'!
updateStatus
	self changed: #statusText; changed: #statusColor.! !

TestCase subclass: #ESLintTestCase
	instanceVariableNames: 'mode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/26/2005 21:15'!
buildAll
	BasicLintRule withAllSubclassesDo: [ :each | self buildForClass: each ].! !

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/11/2005 22:18'!
buildForClass: aClass
	aClass protocols do: [ :each | self buildForClass: aClass protocol: each ].! !

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/11/2005 22:20'!
buildForClass: aClass protocol: aProtocol 
	(aClass class organization listAtCategoryNamed: aProtocol)
		do: [ :each | self buildForClass: aClass protocol: aProtocol method: each ].! !

!ESLintTestCase class methodsFor: 'private' stamp: 'lr 10/26/2005 21:27'!
buildForClass: aClass protocol: aProtocol method: aSelector
	| selector |
	selector := String streamContents: [ :stream |
		stream nextPut: aSelector first asUppercase.
		stream nextPutAll: aSelector allButFirst ].
	self
		compile: (String streamContents: [ :stream |
			stream nextPutAll: 'test'; nextPutAll: selector; cr.
			stream tab; nextPutAll: 'self'; cr.
			stream tab; tab; nextPutAll: 'run: '; print: aClass; space; nextPutAll: aSelector; cr.
			stream tab; tab; nextPutAll: 'scope: self scope'; nextPutAll: selector; cr.
			stream tab; tab; nextPutAll: 'context: self context.' ])
		classified: (String streamContents: [ :stream |
			stream nextPutAll: 'testing-'.
			aProtocol readStream in: [ :input |
				[ input atEnd ] whileFalse: [
					stream nextPutAll: (input upTo: Character space).
					input atEnd ifFalse: [ stream nextPut: $- ] ] ] ]).
	self
		compile: (String streamContents: [ :stream |
			stream nextPutAll: 'scope'; nextPut: aSelector first asUppercase.
			stream nextPutAll: aSelector allButFirst; cr; tab.
			stream nextPutAll: '^ self scope.' ])
		classified: (String streamContents: [ :stream |
			stream nextPutAll: 'scope-'.
			aProtocol readStream in: [ :input |
				[ input atEnd ] whileFalse: [
					stream nextPutAll: (input upTo: Character space).
					input atEnd ifFalse: [ stream nextPut: $- ] ] ] ]).! !

!ESLintTestCase class methodsFor: 'testing' stamp: 'lr 10/26/2005 17:27'!
isAbstract
	^ super isAbstract or: [ self sunitName = #ESLintTestCase ].! !

!ESLintTestCase class methodsFor: 'accessing' stamp: 'lr 10/26/2005 17:25'!
resources
	^ Array with: ESLintTestResource.! !

!ESLintTestCase methodsFor: 'accessing' stamp: 'lr 10/26/2005 15:45'!
context
	" Answer the lint-context to be used with this test-case. "

	^ self resource context.! !

!ESLintTestCase methodsFor: 'running' stamp: 'lr 10/26/2005 22:21'!
debug
	mode := #debug.
	self run.! !

!ESLintTestCase methodsFor: 'accessing' stamp: 'lr 10/26/2005 21:22'!
environment
 	" Answer a browser environment that is used for this test. Override this message in your subclasses to select the desired package. "
	
	^ BrowserEnvironment new.! !

!ESLintTestCase methodsFor: 'private' stamp: 'lr 10/26/2005 15:52'!
isDebugging
	^ mode = #debug.! !

!ESLintTestCase methodsFor: 'private' stamp: 'lr 10/26/2005 17:26'!
resource
	^ self class resources first current.! !

!ESLintTestCase methodsFor: 'running' stamp: 'lr 10/26/2005 22:21'!
run: aLintRule scope: aLintScope context: aLintContext
	| result |
	result := aLintScope run: aLintRule in: aLintContext.
	result problemCount isZero ifFalse: [
		self isDebugging
			ifTrue: [ aLintRule result label: aLintRule name; openEditor ]
			ifFalse: [ self assert: false description: aLintRule name ] ].! !

!ESLintTestCase methodsFor: 'accessing' stamp: 'lr 10/26/2005 21:22'!
scope
 	" Answer a new scope within the given environment to be used with this test-case. "
	
	^ ESLintScope on: (self resource environmentFor: self).! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeAbstractClass
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeAddRemoveDependents
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeAsOrderedCollectionNotNeeded
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeAssignmentInBlock
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeAssignmentInIfTrue
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeAtIfAbsent
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeBadMessage
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeBooleanPrecedence
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeClassInstVarNotInitialized
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeClassNameInSelector
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
scopeClassNotReferenced
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeCollectSelectNotUsed
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeCollectionCopyEmpty
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeCollectionMessagesToExternalObject
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeCollectionProtocol
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeConsistencyCheck
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeContains
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeDefinesEqualNotHash
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeDetectContains
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
scopeEndTrueFalse
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeEqualNotUsed
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
scopeEqualsTrue
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
scopeEquivalentSuperclassMethods
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
scopeExtraBlock
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeFileBlocks
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeFullBlocks
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeGuardingClause
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeIfTrueBlocks
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeIfTrueReturns
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
scopeImplementedNotSent
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeInstVarInSubclasses
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
scopeJustSendsSuper
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeLiteralArrayCharacters
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeLiteralArrayContainsComma
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeLongMethods
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeMinMax
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:28'!
scopeMissingSubclassResponsibility
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeMissingYourself
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeModifiesCollection
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
scopeOnlyReadOrWritten
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeOverridesSpecialMessage
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopePrecedence
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeRefersToClass
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeReturnInEnsure
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeReturnsBooleanAndOther
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeReturnsIfTrue
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeSearchingLiteral
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeSendsDifferentSuper
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeSentNotImplemented
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeSizeCheck
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeStringConcatenation
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeSubclassResponsibilityNotDefined
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeSuperSends
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeTempVarOverridesInstVar
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeTempsReadBeforeWritten
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeThreeElementPoint
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeToDo
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeToDoCollect
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeToDoWithIncrement
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeUndeclaredReference
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
scopeUnnecessaryAssignment
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeUnoptimizedAndOr
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeUnoptimizedToDo
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
scopeUnreferencedVariables
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeUsesAdd
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeUsesTrue
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeUtilityMethods
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
scopeVariableAssignedLiteral
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-bugs' stamp: 'lr 10/26/2005 21:27'!
scopeVariableNotDefined
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
scopeVariableReferencedOnce
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
scopeWhileTrue
	^ self scope.! !

!ESLintTestCase methodsFor: 'scope-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
scopeYourselfNotUsed
	^ self scope.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testAbstractClass
	self
		run: BlockLintRule abstractClass
		scope: self scopeAbstractClass
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testAddRemoveDependents
	self
		run: BlockLintRule addRemoveDependents
		scope: self scopeAddRemoveDependents
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testAsOrderedCollectionNotNeeded
	self
		run: ParseTreeLintRule asOrderedCollectionNotNeeded
		scope: self scopeAsOrderedCollectionNotNeeded
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testAssignmentInBlock
	self
		run: ParseTreeLintRule assignmentInBlock
		scope: self scopeAssignmentInBlock
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testAssignmentInIfTrue
	self
		run: ParseTreeLintRule assignmentInIfTrue
		scope: self scopeAssignmentInIfTrue
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testAtIfAbsent
	self
		run: ParseTreeLintRule atIfAbsent
		scope: self scopeAtIfAbsent
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testBadMessage
	self
		run: BlockLintRule badMessage
		scope: self scopeBadMessage
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testBooleanPrecedence
	self
		run: ParseTreeLintRule booleanPrecedence
		scope: self scopeBooleanPrecedence
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testClassInstVarNotInitialized
	self
		run: BlockLintRule classInstVarNotInitialized
		scope: self scopeClassInstVarNotInitialized
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testClassNameInSelector
	self
		run: BlockLintRule classNameInSelector
		scope: self scopeClassNameInSelector
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
testClassNotReferenced
	self
		run: BlockLintRule classNotReferenced
		scope: self scopeClassNotReferenced
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testCollectSelectNotUsed
	self
		run: ParseTreeLintRule collectSelectNotUsed
		scope: self scopeCollectSelectNotUsed
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testCollectionCopyEmpty
	self
		run: BlockLintRule collectionCopyEmpty
		scope: self scopeCollectionCopyEmpty
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testCollectionMessagesToExternalObject
	self
		run: ParseTreeLintRule collectionMessagesToExternalObject
		scope: self scopeCollectionMessagesToExternalObject
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testCollectionProtocol
	self
		run: ParseTreeLintRule collectionProtocol
		scope: self scopeCollectionProtocol
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testConsistencyCheck
	self
		run: ParseTreeLintRule consistencyCheck
		scope: self scopeConsistencyCheck
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testContains
	self
		run: ParseTreeLintRule contains
		scope: self scopeContains
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testDefinesEqualNotHash
	self
		run: BlockLintRule definesEqualNotHash
		scope: self scopeDefinesEqualNotHash
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testDetectContains
	self
		run: ParseTreeLintRule detectContains
		scope: self scopeDetectContains
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
testEndTrueFalse
	self
		run: ParseTreeLintRule endTrueFalse
		scope: self scopeEndTrueFalse
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testEqualNotUsed
	self
		run: ParseTreeLintRule equalNotUsed
		scope: self scopeEqualNotUsed
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
testEqualsTrue
	self
		run: ParseTreeLintRule equalsTrue
		scope: self scopeEqualsTrue
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
testEquivalentSuperclassMethods
	self
		run: BlockLintRule equivalentSuperclassMethods
		scope: self scopeEquivalentSuperclassMethods
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
testExtraBlock
	self
		run: ParseTreeLintRule extraBlock
		scope: self scopeExtraBlock
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testFileBlocks
	self
		run: ParseTreeLintRule fileBlocks
		scope: self scopeFileBlocks
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testFullBlocks
	self
		run: BlockLintRule fullBlocks
		scope: self scopeFullBlocks
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testGuardingClause
	self
		run: ParseTreeLintRule guardingClause
		scope: self scopeGuardingClause
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testIfTrueBlocks
	self
		run: ParseTreeLintRule ifTrueBlocks
		scope: self scopeIfTrueBlocks
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testIfTrueReturns
	self
		run: ParseTreeLintRule ifTrueReturns
		scope: self scopeIfTrueReturns
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
testImplementedNotSent
	self
		run: BlockLintRule implementedNotSent
		scope: self scopeImplementedNotSent
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testInstVarInSubclasses
	self
		run: BlockLintRule instVarInSubclasses
		scope: self scopeInstVarInSubclasses
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
testJustSendsSuper
	self
		run: BlockLintRule justSendsSuper
		scope: self scopeJustSendsSuper
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testLiteralArrayCharacters
	self
		run: ParseTreeLintRule literalArrayCharacters
		scope: self scopeLiteralArrayCharacters
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testLiteralArrayContainsComma
	self
		run: BlockLintRule literalArrayContainsComma
		scope: self scopeLiteralArrayContainsComma
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testLongMethods
	self
		run: BlockLintRule longMethods
		scope: self scopeLongMethods
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testMinMax
	self
		run: ParseTreeLintRule minMax
		scope: self scopeMinMax
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:28'!
testMissingSubclassResponsibility
	self
		run: BlockLintRule missingSubclassResponsibility
		scope: self scopeMissingSubclassResponsibility
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testMissingYourself
	self
		run: ParseTreeLintRule missingYourself
		scope: self scopeMissingYourself
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testModifiesCollection
	self
		run: ParseTreeLintRule modifiesCollection
		scope: self scopeModifiesCollection
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
testOnlyReadOrWritten
	self
		run: BlockLintRule onlyReadOrWritten
		scope: self scopeOnlyReadOrWritten
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testOverridesSpecialMessage
	self
		run: BlockLintRule overridesSpecialMessage
		scope: self scopeOverridesSpecialMessage
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testPrecedence
	self
		run: ParseTreeLintRule precedence
		scope: self scopePrecedence
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testRefersToClass
	self
		run: BlockLintRule refersToClass
		scope: self scopeRefersToClass
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testReturnInEnsure
	self
		run: ParseTreeLintRule returnInEnsure
		scope: self scopeReturnInEnsure
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testReturnsBooleanAndOther
	self
		run: BlockLintRule returnsBooleanAndOther
		scope: self scopeReturnsBooleanAndOther
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testReturnsIfTrue
	self
		run: ParseTreeLintRule returnsIfTrue
		scope: self scopeReturnsIfTrue
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testSearchingLiteral
	self
		run: ParseTreeLintRule searchingLiteral
		scope: self scopeSearchingLiteral
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testSendsDifferentSuper
	self
		run: BlockLintRule sendsDifferentSuper
		scope: self scopeSendsDifferentSuper
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testSentNotImplemented
	self
		run: BlockLintRule sentNotImplemented
		scope: self scopeSentNotImplemented
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testSizeCheck
	self
		run: ParseTreeLintRule sizeCheck
		scope: self scopeSizeCheck
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testStringConcatenation
	self
		run: ParseTreeLintRule stringConcatenation
		scope: self scopeStringConcatenation
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testSubclassResponsibilityNotDefined
	self
		run: BlockLintRule subclassResponsibilityNotDefined
		scope: self scopeSubclassResponsibilityNotDefined
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testSuperSends
	self
		run: BlockLintRule superSends
		scope: self scopeSuperSends
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testTempVarOverridesInstVar
	self
		run: BlockLintRule tempVarOverridesInstVar
		scope: self scopeTempVarOverridesInstVar
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testTempsReadBeforeWritten
	self
		run: BlockLintRule tempsReadBeforeWritten
		scope: self scopeTempsReadBeforeWritten
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testThreeElementPoint
	self
		run: ParseTreeLintRule threeElementPoint
		scope: self scopeThreeElementPoint
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testToDo
	self
		run: ParseTreeLintRule toDo
		scope: self scopeToDo
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testToDoCollect
	self
		run: ParseTreeLintRule toDoCollect
		scope: self scopeToDoCollect
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testToDoWithIncrement
	self
		run: ParseTreeLintRule toDoWithIncrement
		scope: self scopeToDoWithIncrement
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testUndeclaredReference
	self
		run: BlockLintRule undeclaredReference
		scope: self scopeUndeclaredReference
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:27'!
testUnnecessaryAssignment
	self
		run: ParseTreeLintRule unnecessaryAssignment
		scope: self scopeUnnecessaryAssignment
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testUnoptimizedAndOr
	self
		run: ParseTreeLintRule unoptimizedAndOr
		scope: self scopeUnoptimizedAndOr
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testUnoptimizedToDo
	self
		run: ParseTreeLintRule unoptimizedToDo
		scope: self scopeUnoptimizedToDo
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
testUnreferencedVariables
	self
		run: BlockLintRule unreferencedVariables
		scope: self scopeUnreferencedVariables
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-possible-bugs' stamp: 'lr 10/26/2005 21:27'!
testUsesAdd
	self
		run: ParseTreeLintRule usesAdd
		scope: self scopeUsesAdd
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testUsesTrue
	self
		run: BlockLintRule usesTrue
		scope: self scopeUsesTrue
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testUtilityMethods
	self
		run: BlockLintRule utilityMethods
		scope: self scopeUtilityMethods
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:28'!
testVariableAssignedLiteral
	self
		run: BlockLintRule variableAssignedLiteral
		scope: self scopeVariableAssignedLiteral
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-bugs' stamp: 'lr 10/26/2005 21:27'!
testVariableNotDefined
	self
		run: BlockLintRule variableNotDefined
		scope: self scopeVariableNotDefined
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-unnecessary-code' stamp: 'lr 10/26/2005 21:28'!
testVariableReferencedOnce
	self
		run: BlockLintRule variableReferencedOnce
		scope: self scopeVariableReferencedOnce
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-intention-revealing' stamp: 'lr 10/26/2005 21:27'!
testWhileTrue
	self
		run: ParseTreeLintRule whileTrue
		scope: self scopeWhileTrue
		context: self context.! !

!ESLintTestCase methodsFor: 'testing-miscellaneous' stamp: 'lr 10/26/2005 21:27'!
testYourselfNotUsed
	self
		run: ParseTreeLintRule yourselfNotUsed
		scope: self scopeYourselfNotUsed
		context: self context.! !

ESLintTestCase subclass: #ESSelfTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Essential-SLint'!

!ESSelfTestCase methodsFor: 'accessing' stamp: 'lr 10/26/2005 21:26'!
environment
	^ super environment forPackage: (PackageInfo named: 'Essential').! !
